# cosipy

The cosipy library is [COSI](https://cosi.ssl.berkeley.edu)'s high-level analysis software.

The main repository is hosted in https://github.com/cositools/cosipy

For the cosipy installation and usage instructions please refer to the main [cosipy documentation](https://cositools.github.io/cosipy/).



